==> axiom-1.4.0-src.zip: axiom-1.4.0/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/document/TestSerializeAndConsume.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.om.document;

import java.io.StringReader;

import org.apache.axiom.om.OMDocument;
import org.apache.axiom.om.OMFactory;
import org.apache.axiom.om.OMMetaFactory;
import org.apache.axiom.om.OMXMLBuilderFactory;
import org.apache.axiom.ts.AxiomTestCase;
import org.apache.commons.io.output.NullOutputStream;

/**
 * Tests the behavior of {@link org.apache.axiom.om.OMContainer#serializeAndConsume(java.io.OutputStream)}
 * when invoked on an {@link OMDocument} instance. This is a regression test for
 * <a href="https://issues.apache.org/jira/browse/AXIOM-24">AXIOM-24</a>.
 */
public class TestSerializeAndConsume extends AxiomTestCase {
    public TestSerializeAndConsume(OMMetaFactory metaFactory) {
        super(metaFactory);
    }

    @Override
    protected void runTest() throws Throwable {
        OMFactory factory = metaFactory.getOMFactory();
        OMDocument document = OMXMLBuilderFactory.createOMBuilder(factory,
                new StringReader("<elem>text</elem>")).getDocument();
        document.serializeAndConsume(NullOutputStream.NULL_OUTPUT_STREAM);
        assertConsumed(document);
    }
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/document/TestSerializeAndConsume.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.om.document;

import java.io.StringReader;

import org.apache.axiom.om.OMDocument;
import org.apache.axiom.om.OMFactory;
import org.apache.axiom.om.OMMetaFactory;
import org.apache.axiom.om.OMXMLBuilderFactory;
import org.apache.axiom.ts.AxiomTestCase;
import org.apache.commons.io.output.NullOutputStream;

/**
 * Tests the behavior of {@link
 * org.apache.axiom.om.OMContainer#serializeAndConsume(java.io.OutputStream)} when invoked on an
 * {@link OMDocument} instance. This is a regression test for <a
 * href="https://issues.apache.org/jira/browse/AXIOM-24">AXIOM-24</a>.
 */
public class TestSerializeAndConsume extends AxiomTestCase {
    public TestSerializeAndConsume(OMMetaFactory metaFactory) {
        super(metaFactory);
    }

    @Override
    protected void runTest() throws Throwable {
        OMFactory factory = metaFactory.getOMFactory();
        OMDocument document =
                OMXMLBuilderFactory.createOMBuilder(factory, new StringReader("<elem>text</elem>"))
                        .getDocument();
        document.serializeAndConsume(NullOutputStream.NULL_OUTPUT_STREAM);
        assertConsumed(document);
    }
}
